@@ -20,7 +20,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = qw(command_line);
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 #{{{sub new
 
@@ -164,21 +164,8 @@ sub check_exists {
 #{{{ sub command_line
 sub command_line {
     my ( $group, @ARGV ) = @_;
-
-    #options parsing
-    my $sling  = Apache::Sling->new;
-    my $config = config($sling);
-
-    GetOptions(
-        $config,      'auth=s',     'help|?',       'log|L=s',
-        'man|M',      'pass|p=s',   'threads|t=s',  'url|U=s',
-        'user|u=s',   'verbose|v+', 'add|a=s',      'additions|A=s',
-        'delete|d=s', 'exists|e=s', 'property|P=s', 'view|V=s'
-    ) or $group->help();
-
-    if ( $sling->{'Help'} ) { $group->help(); }
-    if ( $sling->{'Man'} )  { $group->man(); }
-
+    my $sling = Apache::Sling->new;
+    my $config = $group->config( $sling, @ARGV );
     return $group->run( $sling, $config );
 }
 
@@ -187,7 +174,7 @@ sub command_line {
 #{{{sub config
 
 sub config {
-    my ($sling) = @_;
+    my ( $group, $sling, @ARGV ) = @_;
     my $additions;
     my $add;
     my $delete;
@@ -213,6 +200,16 @@ sub config {
         'view'      => \$view
     );
 
+    GetOptions(
+        \%group_config, 'auth=s',     'help|?',       'log|L=s',
+        'man|M',        'pass|p=s',   'threads|t=s',  'url|U=s',
+        'user|u=s',     'verbose|v+', 'add|a=s',      'additions|A=s',
+        'delete|d=s',   'exists|e=s', 'property|P=s', 'view|V=s'
+    ) or $group->help();
+
+    if ( $sling->{'Help'} ) { $group->help(); }
+    if ( $sling->{'Man'} )  { $group->man(); }
+
     return \%group_config;
 }
 
